==> ejc-zhengyuan-impl-3.0.0-20241227.024427-13-sources.jar: com/ejianc/business/sq/keyan/vo/KeyanAwardSituationVO.java <==
package com.ejianc.business.sq.keyan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 获奖情况
 * 
 * @author generator
 * 
 */
public class KeyanAwardSituationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据审批状态
    private String billCode; // 单据编码
    private Long unitId; // 所属单位id
    private String unitName; // 所属单位名称
    private String prizeCategory; // 奖项类别
    private String prizeLevel; // 奖项级别
    private String awardName; // 获奖名称
    private String achievementName; // 成果（项目）名称
    private String awardLevel; // 获奖等级
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date awardTime; // 获奖时间
    private String awardUnit; // 颁奖单位
    private String awardFields; // 获奖领域
    private String winningUnit; // 获奖单位
    private String mainCompletionPersonnel; // 主要完成人员
    private String remarks; // 备注

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getUnitId() {
        return unitId;
    }

    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getPrizeCategory() {
        return prizeCategory;
    }

    public void setPrizeCategory(String prizeCategory) {
        this.prizeCategory = prizeCategory;
    }
    public String getPrizeLevel() {
        return prizeLevel;
    }

    public void setPrizeLevel(String prizeLevel) {
        this.prizeLevel = prizeLevel;
    }
    public String getAwardName() {
        return awardName;
    }

    public void setAwardName(String awardName) {
        this.awardName = awardName;
    }
    public String getAchievementName() {
        return achievementName;
    }

    public void setAchievementName(String achievementName) {
        this.achievementName = achievementName;
    }
    public String getAwardLevel() {
        return awardLevel;
    }

    public void setAwardLevel(String awardLevel) {
        this.awardLevel = awardLevel;
    }
    public Date getAwardTime() {
        return awardTime;
    }

    public void setAwardTime(Date awardTime) {
        this.awardTime = awardTime;
    }
    public String getAwardUnit() {
        return awardUnit;
    }

    public void setAwardUnit(String awardUnit) {
        this.awardUnit = awardUnit;
    }
    public String getAwardFields() {
        return awardFields;
    }

    public void setAwardFields(String awardFields) {
        this.awardFields = awardFields;
    }
    public String getWinningUnit() {
        return winningUnit;
    }

    public void setWinningUnit(String winningUnit) {
        this.winningUnit = winningUnit;
    }
    public String getMainCompletionPersonnel() {
        return mainCompletionPersonnel;
    }

    public void setMainCompletionPersonnel(String mainCompletionPersonnel) {
        this.mainCompletionPersonnel = mainCompletionPersonnel;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-zhengyuan-impl-3.0.0-20250821.081133-43-sources.jar: com/ejianc/business/sq/keyan/vo/KeyanAwardSituationVO.java <==
package com.ejianc.business.sq.keyan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 获奖情况
 * 
 * @author generator
 * 
 */
public class KeyanAwardSituationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据审批状态
    private String billCode; // 单据编码
    private Long unitId; // 所属单位id
    private String unitName; // 所属单位名称
    private String prizeCategory; // 奖项类别
    private String prizeLevel; // 奖项级别
    private String awardName; // 获奖名称
    private String achievementName; // 成果（项目）名称
    private String awardLevel; // 获奖等级
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date awardTime; // 获奖时间
    private String awardUnit; // 颁奖单位
    private String awardFields; // 获奖领域
    private String winningUnit; // 获奖单位
    private String mainCompletionPersonnel; // 主要完成人员
    private String remarks; // 备注

    private String errorMsg; // 导入错误信息
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getUnitId() {
        return unitId;
    }

    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getPrizeCategory() {
        return prizeCategory;
    }

    public void setPrizeCategory(String prizeCategory) {
        this.prizeCategory = prizeCategory;
    }
    public String getPrizeLevel() {
        return prizeLevel;
    }

    public void setPrizeLevel(String prizeLevel) {
        this.prizeLevel = prizeLevel;
    }
    public String getAwardName() {
        return awardName;
    }

    public void setAwardName(String awardName) {
        this.awardName = awardName;
    }
    public String getAchievementName() {
        return achievementName;
    }

    public void setAchievementName(String achievementName) {
        this.achievementName = achievementName;
    }
    public String getAwardLevel() {
        return awardLevel;
    }

    public void setAwardLevel(String awardLevel) {
        this.awardLevel = awardLevel;
    }
    public Date getAwardTime() {
        return awardTime;
    }

    public void setAwardTime(Date awardTime) {
        this.awardTime = awardTime;
    }
    public String getAwardUnit() {
        return awardUnit;
    }

    public void setAwardUnit(String awardUnit) {
        this.awardUnit = awardUnit;
    }
    public String getAwardFields() {
        return awardFields;
    }

    public void setAwardFields(String awardFields) {
        this.awardFields = awardFields;
    }
    public String getWinningUnit() {
        return winningUnit;
    }

    public void setWinningUnit(String winningUnit) {
        this.winningUnit = winningUnit;
    }
    public String getMainCompletionPersonnel() {
        return mainCompletionPersonnel;
    }

    public void setMainCompletionPersonnel(String mainCompletionPersonnel) {
        this.mainCompletionPersonnel = mainCompletionPersonnel;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
    
}
